Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(241)

Unified Diff: dart/sdk/lib/isolate/timer.dart

Issue 11615023: Version 0.2.9.7 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dart/sdk/lib/_internal/libraries.dart ('k') | dart/tools/VERSION » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/sdk/lib/isolate/timer.dart
===================================================================
--- dart/sdk/lib/isolate/timer.dart (revision 16250)
+++ dart/sdk/lib/isolate/timer.dart (working copy)
@@ -5,15 +5,15 @@
abstract class Timer {
/**
* Creates a new timer. The [callback] callback is invoked after
- * [milliseconds] milliseconds.
+ * [milliSeconds] milliseconds.
*/
- external factory Timer(int milliseconds, void callback(Timer timer));
+ external factory Timer(int milliSeconds, void callback(Timer timer));
/**
* Creates a new repeating timer. The [callback] is invoked every
* [milliseconds] millisecond until cancelled.
*/
- external factory Timer.repeating(int milliseconds,
+ external factory Timer.repeating(int milliSeconds,
void callback(Timer timer));
/**
« no previous file with comments | « dart/sdk/lib/_internal/libraries.dart ('k') | dart/tools/VERSION » ('j') | no next file with comments »
@@ -5,15 +5,15 @@
/**
* Creates a new repeating timer. The [callback] is invoked every
- * [milliseconds] millisecond until cancelled.
+ * [milliSeconds] millisecond until cancelled.
*/

Powered by Google App Engine
This is Rietveld 408576698